@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
 """Function/variables common to all the commands"""
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import email.utils
 import os
@@ -46,15 +44,12 @@ along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 
-# Command exception class
 class CmdException(StgException):
     pass
 
 
-# Utility functions
 def parse_rev(rev):
-    """Parse a revision specification into its branch:patch parts.
-    """
+    """Parse a revision specification into its branch:patch parts."""
     try:
         branch, patch = rev.split(':', 1)
     except ValueError:
@@ -64,21 +59,13 @@ def parse_rev(rev):
     return (branch, patch)
 
 
-def get_public_ref(branch_name):
-    """Return the public ref of the branch."""
-    public_ref = config.get('branch.%s.public' % branch_name)
-    if not public_ref:
-        public_ref = 'refs/heads/%s.public' % branch_name
-    return public_ref
-
-
 def git_commit(name, repository, branch_name=None):
     """Return the a Commit object if 'name' is a patch name or Git commit.
-    The patch names allowed are in the form '<branch>:<patch>' and can
-    be followed by standard symbols used by git rev-parse. If <patch>
-    is '{base}', it represents the bottom of the stack. If <patch> is
-    {public}, it represents the public branch corresponding to the stack as
-    described in the 'publish' command.
+
+    The patch names allowed are in the form '<branch>:<patch>' and can be followed by
+    standard symbols used by ``git rev-parse``. If <patch> is '{base}', it represents
+    the bottom of the stack.
+
     """
     # Try a [branch:]patch name first
     branch, patch = parse_rev(name)
@@ -89,11 +76,6 @@ def git_commit(name, repository, branch_name=None):
     if patch.startswith('{base}'):
         base_id = repository.get_stack(branch).base.sha1
         return repository.rev_parse(base_id + strip_prefix('{base}', patch))
-    elif patch.startswith('{public}'):
-        public_ref = get_public_ref(branch)
-        return repository.rev_parse(
-            public_ref + strip_prefix('{public}', patch), discard_stderr=True
-        )
 
     # Other combination of branch and patch
     try:
@@ -111,8 +93,7 @@ def git_commit(name, repository, branch_name=None):
 
 
 def color_diff_flags():
-    """Return the git flags for coloured diff output if the configuration and
-    stdout allows."""
+    """Return the Git flags for coloured diff output if allowed."""
     stdout_is_tty = (sys.stdout.isatty() and 'true') or 'false'
     if config.get_colorbool('color.diff', stdout_is_tty) == 'true':
         return ['--color']
@@ -167,9 +148,10 @@ def get_patch_from_list(part_name, patch_list):
 
 
 def parse_patches(patch_args, patch_list, boundary=0, ordered=False):
-    """Parse patch_args list for patch names in patch_list and return
-    a list. The names can be individual patches and/or in the
-    patch1..patch2 format.
+    """Parse patch_args list for patch names in patch_list.
+
+    The names can be individual patches and/or in the 'patch1..patch2' format.
+
     """
     # in case it receives a tuple
     patch_list = list(patch_list)
@@ -242,8 +224,11 @@ def name_email(address):
 
 
 def address_or_alias(addr_pair):
-    """Return a name-email tuple the e-mail address is valid or look up
-    the aliases in the config files.
+    """Pass-through name/email address or lookup alias from config.
+
+    Returns a name-email tuple if the e-mail address is valid, otherwise looks up the
+    alias in the config files.
+
     """
     addr = addr_pair[1]
     if '@' in addr:
@@ -349,37 +334,34 @@ def post_rebase(stack, applied, cmd_name, check_merged):
 #
 # Patch description/e-mail/diff parsing
 #
-def __end_descr(line):
-    return (
-        re.match(br'---\s*$', line)
-        or re.match(b'diff -', line)
-        or re.match(b'Index: ', line)
-        or re.match(br'--- \w', line)
+def __split_descr_diff(string):
+    """Return the description and the diff from the given string."""
+    m = re.search(
+        br'''
+        ^
+        (?:
+               --- \s*
+             | --- \s \w
+             | diff \s -
+             | Index: \s
+        )
+        ''',
+        string,
+        re.MULTILINE | re.VERBOSE,
     )
 
+    if m:
+        desc = string[: m.start()]
+        diff = string[m.start() :]
+    else:
+        desc = string
+        diff = b''
 
-def __split_descr_diff(string):
-    """Return the description and the diff from the given string
-    """
-    descr = diff = b''
-    top = True
-
-    for line in string.split(b'\n'):
-        if top:
-            if not __end_descr(line):
-                descr += line + b'\n'
-                continue
-            else:
-                top = False
-        diff += line + b'\n'
-
-    return (descr.rstrip() + b'\n', diff)
+    return desc, diff
 
 
 def __parse_description(descr):
-    """Parse the patch description and return the new description and
-    author information (if any).
-    """
+    """Parse the patch description for author information."""
     subject = ''
     authname = authemail = authdate = None
 
@@ -443,26 +425,29 @@ def parse_patch(patch_data, contains_diff):
 def run_commit_msg_hook(repo, cd, editor_is_used=True):
     """Run the commit-msg hook (if any) on a commit.
 
-    @param cd: The L{CommitData<stgit.lib.git.CommitData>} to run the
-               hook on.
+    :param cd: The :class:`stgit.lib.git.CommitData` to run the hook on.
 
-    Return the new L{CommitData<stgit.lib.git.CommitData>}."""
+    :returns: the new :class:`stgit.lib.git.CommitData`
+
+    """
     env = dict(cd.env)
     if not editor_is_used:
         env['GIT_EDITOR'] = ':'
     commit_msg_hook = get_hook(repo, 'commit-msg', env)
 
-    try:
-        new_msg = run_hook_on_bytes(commit_msg_hook, cd.message)
-    except RunException as exc:
-        raise EditorException(str(exc))
+    if commit_msg_hook:
+        try:
+            new_msg = run_hook_on_bytes(commit_msg_hook, cd.message)
+        except RunException as exc:
+            raise EditorException(str(exc))
 
-    return cd.set_message(new_msg)
+        return cd.set_message(new_msg)
+    else:
+        return cd
 
 
 def update_commit_data(cd, message=None, author=None, sign_str=None, edit=False):
-    """Return a new CommitData object updated according to the command line
-    options."""
+    """Create updated CommitData according to the command line options."""
     # Set the commit message from commandline.
     if message is not None:
         cd = cd.set_message(message)
@@ -482,7 +467,7 @@ def update_commit_data(cd, message=None, author=None, sign_str=None, edit=False)
     if edit:
         tmpl = templates.get_template('patchdescr.tmpl')
         if tmpl:
-            cd = cd.set_message(cd.message + tmpl)
+            cd = cd.set_message(cd.message_str + tmpl)
         cd = cd.set_message(edit_bytes(cd.message, '.stgit-new.txt'))
 
     return cd
@@ -492,14 +477,12 @@ class DirectoryException(StgException):
     pass
 
 
-class DirectoryAnywhere(object):
+class DirectoryAnywhere:
     def setup(self):
         pass
 
 
-class DirectoryHasRepository(object):
-    """For commands that use the new infrastructure in stgit.lib.*."""
-
+class DirectoryHasRepository:
     def setup(self):
         # This will throw an exception if we don't have a repository.
         self.repository = StackRepository.default()
