@@ -1,8 +1,5 @@
-# -*- coding: utf-8 -*-
 """Export command"""
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import io
 import os
 import sys
@@ -10,7 +7,6 @@ import sys
 from stgit import templates
 from stgit.argparse import diff_opts_option, opt, patch_range
 from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
-from stgit.lib.git import diffstat
 from stgit.out import out
 
 __copyright__ = """
@@ -60,9 +56,16 @@ options = [
         short='Export patches to DIR instead of the default',
     ),
     opt(
-        '-p', '--patch', action='store_true', short='Append .patch to the patch names',
+        '-p',
+        '--patch',
+        action='store_true',
+        short='Append .patch to the patch names',
+    ),
+    opt(
+        '-e',
+        '--extension',
+        short='Append .EXTENSION to the patch names',
     ),
-    opt('-e', '--extension', short='Append .EXTENSION to the patch names'),
     opt(
         '-n',
         '--numbered',
@@ -94,8 +97,7 @@ directory = DirectoryHasRepository()
 
 
 def func(parser, options, args):
-    """Export a range of patches.
-    """
+    """Export a range of patches."""
     repository = directory.repository
     stack = repository.get_stack(options.branch)
 
@@ -140,9 +142,7 @@ def func(parser, options, args):
         series = io.open(os.path.join(dirname, 'series'), 'w')
         # note the base commit for this series
         base_commit = stack.base.sha1
-        print(
-            '# This series applies on GIT commit %s' % base_commit, file=series,
-        )
+        print('# This series applies on GIT commit %s' % base_commit, file=series)
 
     for patch_no, p in enumerate(patches, 1):
         pname = p
@@ -167,14 +167,14 @@ def func(parser, options, args):
         long_descr = '\n'.join(descr_lines[1:]).strip()
 
         diff = stack.repository.diff_tree(
-            cd.parent.data.tree, cd.tree, options.diff_flags,
+            cd.parent.data.tree, cd.tree, options.diff_flags
         )
 
         tmpl_dict = {
             'description': descr,
             'shortdescr': short_descr,
             'longdescr': long_descr,
-            'diffstat': diffstat(diff).rstrip(),
+            'diffstat': repository.default_iw.diffstat(diff).rstrip(),
             'authname': cd.author.name,
             'authemail': cd.author.email,
             'authdate': cd.author.date.isoformat(),
@@ -192,10 +192,7 @@ def func(parser, options, args):
             )
 
         if options.stdout:
-            if hasattr(sys.stdout, 'buffer'):
-                f = sys.stdout.buffer
-            else:
-                f = sys.stdout
+            f = sys.stdout.buffer
         else:
             f = io.open(pfile, 'wb')
 
