@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import io
 import os
 import sys
@@ -76,8 +73,7 @@ directory = DirectoryHasRepository()
 
 
 def func(parser, options, args):
-    """Integrate a GNU diff patch into the current patch
-    """
+    """Integrate a GNU diff patch into the current patch"""
     if len(args) > 1:
         parser.error('incorrect number of arguments')
 
@@ -108,10 +104,7 @@ def func(parser, options, args):
             raise CmdException('No such file: %s' % filename)
     else:
         out.start('Folding patch from stdin')
-        if hasattr(sys.stdin, 'buffer'):
-            diff = sys.stdin.buffer.read()
-        else:
-            diff = sys.stdin.read()
+        diff = sys.stdin.buffer.read()
 
     if options.threeway:
         top_patch = stack.patches.get(current)
@@ -132,7 +125,10 @@ def func(parser, options, args):
         )
     else:
         apply_patch(
-            stack, diff, strip=options.strip, reject=options.reject,
+            stack,
+            diff,
+            strip=options.strip,
+            reject=options.reject,
         )
 
     out.done()
