@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.commands.common import DirectoryHasRepository
 from stgit.lib.stack import Stack
 
@@ -35,8 +32,7 @@ directory = DirectoryHasRepository()
 
 
 def func(parser, options, args):
-    """Performs the repository initialisation
-    """
+    """Performs the repository initialisation"""
     if len(args) != 0:
         parser.error('incorrect number of arguments')
 
