@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit import argparse
 from stgit.argparse import opt
 from stgit.commands.common import CmdException, DirectoryHasRepository, color_diff_flags
@@ -35,7 +32,10 @@ files."""
 args = ['known_files']
 options = [
     opt(
-        '-d', '--diff', action='store_true', short='Show the diff for the given files',
+        '-d',
+        '--diff',
+        action='store_true',
+        short='Show the diff for the given files',
     ),
     opt(
         '-b',
