@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import opt, patch_range
 from stgit.commands.common import (
     CmdException,
@@ -18,7 +15,7 @@ from stgit.lib.git import CommitData, MergeConflictException, MergeException, Pe
 from stgit.lib.transaction import StackTransaction, TransactionHalted
 from stgit.out import out
 from stgit.run import Run
-from stgit.utils import STGIT_CONFLICT, STGIT_SUCCESS, find_patch_name, make_patch_name
+from stgit.utils import STGIT_CONFLICT, STGIT_SUCCESS
 
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
@@ -57,9 +54,23 @@ message.
 
 args = [patch_range('applied_patches', 'unapplied_patches', 'hidden_patches')]
 options = [
-    opt('-n', '--name', short='Use NAME as the patch name',),
-    opt('-B', '--ref-branch', args=['stg_branches'], short='Pick patches from BRANCH',),
-    opt('-r', '--revert', action='store_true', short='Revert the given commit object',),
+    opt(
+        '-n',
+        '--name',
+        short='Use NAME as the patch name',
+    ),
+    opt(
+        '-B',
+        '--ref-branch',
+        args=['stg_branches'],
+        short='Pick patches from BRANCH',
+    ),
+    opt(
+        '-r',
+        '--revert',
+        action='store_true',
+        short='Revert the given commit object',
+    ),
     opt(
         '-p',
         '--parent',
@@ -89,7 +100,11 @@ options = [
         action='append',
         short='Only fold the given file (can be used multiple times)',
     ),
-    opt('--unapplied', action='store_true', short='Keep the patch unapplied',),
+    opt(
+        '--unapplied',
+        action='store_true',
+        short='Keep the patch unapplied',
+    ),
 ]
 
 directory = DirectoryGotoTopLevel()
@@ -105,9 +120,9 @@ def __pick_commit(stack, ref_stack, iw, commit, patchname, options):
         patchname = 'revert-' + patchname
 
     if patchname:
-        patchname = find_patch_name(patchname, stack.patches.exists)
+        patchname = stack.patches.make_name(patchname, lower=False)
     else:
-        patchname = make_patch_name(commit.data.message_str, stack.patches.exists)
+        patchname = stack.patches.make_name(commit.data.message_str)
 
     if options.parent:
         parent = git_commit(options.parent, repository, ref_stack.name)
@@ -140,7 +155,9 @@ def __pick_commit(stack, ref_stack, iw, commit, patchname, options):
                 else:
                     try:
                         iw.merge(
-                            bottom.data.tree, stack.head.data.tree, top.data.tree,
+                            bottom.data.tree,
+                            stack.head.data.tree,
+                            top.data.tree,
                         )
                     except MergeConflictException as e:
                         out.done('%s conflicts' % len(e.conflicts))
@@ -200,7 +217,10 @@ def __pick_commit(stack, ref_stack, iw, commit, patchname, options):
 
         new_commit = repository.commit(
             CommitData(
-                tree=top.data.tree, parents=[bottom], message=message, author=author,
+                tree=top.data.tree,
+                parents=[bottom],
+                message=message,
+                author=author,
             )
         )
 
@@ -227,8 +247,7 @@ def __pick_commit(stack, ref_stack, iw, commit, patchname, options):
 
 
 def func(parser, options, args):
-    """Import a commit object as a new patch
-    """
+    """Import a commit object as a new patch"""
     if not args:
         parser.error('incorrect number of arguments')
 
@@ -251,7 +270,9 @@ def func(parser, options, args):
 
     try:
         patches = parse_patches(
-            args, ref_stack.patchorder.all_visible, len(ref_stack.patchorder.applied),
+            args,
+            ref_stack.patchorder.all_visible,
+            len(ref_stack.patchorder.applied),
         )
         commit = None
     except CmdException:
