@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import opt
 from stgit.commands.common import (
     CmdException,
@@ -66,8 +63,7 @@ directory = DirectoryGotoTopLevel()
 
 
 def func(parser, options, args):
-    """Rebase the current stack
-    """
+    """Rebase the current stack"""
     if len(args) != 1:
         parser.error('incorrect number of arguments')
 
