@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit import argparse, utils
 from stgit.argparse import opt
 from stgit.commands.common import (
@@ -11,8 +8,14 @@ from stgit.commands.common import (
 from stgit.config import config
 from stgit.lib.edit import auto_edit_patch, interactive_edit_patch
 from stgit.lib.git import CommitData, IndexAndWorktree
-from stgit.lib.transaction import StackTransaction, TransactionHalted
+from stgit.lib.transaction import (
+    StackTransaction,
+    TransactionException,
+    TransactionHalted,
+)
 from stgit.out import out
+from stgit.run import RunException
+from stgit.utils import get_hook
 
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
@@ -58,7 +61,10 @@ squash.
 The creation of the temporary patch is recorded in a separate entry in
 the patch stack log; this means that one undo step will undo the merge
 between the other patch and the temp patch, and two undo steps will
-additionally get rid of the temp patch."""
+additionally get rid of the temp patch.
+
+Additionally, the '--spill' option resets the topmost patch, emptying
+the patch while leaving the patch's changes intact in the worktree."""
 
 args = ['dirty_files']
 options = (
@@ -99,7 +105,12 @@ options = (
             action='store_true',
             short='Invoke an editor for the patch description',
         ),
-        opt('-a', '--annotate', metavar='NOTE', short='Annotate the patch log entry',),
+        opt(
+            '-a',
+            '--annotate',
+            metavar='NOTE',
+            short='Annotate the patch log entry',
+        ),
         opt(
             '-s',
             '--submodules',
@@ -112,6 +123,12 @@ options = (
             dest='submodules',
             short='Exclude submodules when refreshing patch contents',
         ),
+        opt(
+            '--spill',
+            action='store_true',
+            dest='spill',
+            short='Spill patch content to worktree and index, erasing patch content.',
+        ),
     ]
     + (
         argparse.message_options(save_template=False)
@@ -139,12 +156,10 @@ def get_patch(stack, given_patch):
         return stack.patchorder.applied[-1]
 
 
-def list_files(stack, patch_name, args, index, update, submodules):
+def list_files(stack, patch_name, path_limits, update, submodules):
     """Figure out which files to update."""
-    if index:
-        # --index: Don't update the index.
-        return set()
-    paths = stack.repository.default_iw.changed_files(stack.head.data.tree, args or [])
+    iw = stack.repository.default_iw
+    paths = iw.changed_files(stack.head.data.tree, path_limits or [])
     if update:
         # --update: Restrict update to the paths that were already
         # part of the patch.
@@ -156,15 +171,20 @@ def list_files(stack, patch_name, args, index, update, submodules):
         # run "git submodule update" prior to running stg refresh. We won't
         # exclude them if we're explicitly told to include them, or if we're
         # given explicit paths.
-        if not args and not submodules:
+        if not path_limits and not submodules:
             paths -= stack.repository.submodules(stack.head.data.tree)
     return paths
 
 
-def write_tree(stack, paths, temp_index):
+def write_tree(stack, paths, use_temp_index):
     """Possibly update the index, and then write its tree.
-    @return: The written tree.
-    @rtype: L{Tree<stgit.git.Tree>}"""
+
+    If any path limiting is in effect, use a temp index.
+
+    :return: The written tree.
+    :rtype: :class:`Tree<stgit.git.Tree>`
+
+    """
 
     def go(index):
         if paths:
@@ -172,7 +192,7 @@ def write_tree(stack, paths, temp_index):
             iw.update_index(paths)
         return index.write_tree()
 
-    if temp_index:
+    if use_temp_index:
         index = stack.repository.temp_index()
         try:
             index.read_tree(stack.head)
@@ -184,16 +204,16 @@ def write_tree(stack, paths, temp_index):
         return go(stack.repository.default_index)
 
 
-def make_temp_patch(stack, patch_name, paths, temp_index):
-    """Commit index to temp patch, in a complete transaction. If any path
-    limiting is in effect, use a temp index."""
-    tree = write_tree(stack, paths, temp_index)
+def make_temp_patch(stack, patch_name, tree):
+    """Commit tree to temp patch, in a complete transaction."""
     commit = stack.repository.commit(
         CommitData(
-            tree=tree, parents=[stack.head], message='Refresh of %s' % patch_name,
+            tree=tree,
+            parents=[stack.head],
+            message='Refresh of %s' % patch_name,
         )
     )
-    temp_name = utils.make_patch_name('refresh-temp', stack.patches.exists)
+    temp_name = stack.patches.make_name('refresh-temp')
     trans = StackTransaction(stack, 'refresh (create temporary patch)')
     trans.patches[temp_name] = commit
     trans.applied.append(temp_name)
@@ -204,14 +224,16 @@ def make_temp_patch(stack, patch_name, paths, temp_index):
 
 
 def absorb_applied(trans, iw, patch_name, temp_name, edit_fun):
-    """Absorb the temp patch (C{temp_name}) into the given patch
-    (C{patch_name}), which must be applied. If the absorption
-    succeeds, call C{edit_fun} on the resulting
-    L{CommitData<stgit.lib.git.CommitData>} before committing it and
-    commit the return value.
+    """Absorb temp patch into the given patch, which must be applied.
 
-    @return: C{True} if we managed to absorb the temp patch, C{False}
-             if we had to leave it for the user to deal with."""
+    If the absorption succeeds, call ``edit_fun`` on the resulting
+    :class:`stgit.lib.git.CommitData` before committing it, then commit the return
+    value.
+
+    :returns: True if the temp patch is successfully absorbed or False if there remain
+              conflicts for the user to resolve
+
+    """
     temp_absorbed = False
     try:
         # Pop any patch on top of the patch we're refreshing.
@@ -242,16 +264,17 @@ def absorb_applied(trans, iw, patch_name, temp_name, edit_fun):
 
 
 def absorb_unapplied(trans, iw, patch_name, temp_name, edit_fun):
-    """Absorb the temp patch (C{temp_name}) into the given patch
-    (C{patch_name}), which must be unapplied. If the absorption
-    succeeds, call C{edit_fun} on the resulting
-    L{CommitData<stgit.lib.git.CommitData>} before committing it and
-    commit the return value.
+    """Absorb the temp patch into the given patch, which must be unapplied.
 
-    @param iw: Not used.
-    @return: C{True} if we managed to absorb the temp patch, C{False}
-             if we had to leave it for the user to deal with."""
+    If the absorption succeeds, call ``edit_fun`` on the resulting
+    :class:`stgit.lib.git.CommitData` before committing it, then commit the return
+    value.
 
+    :param iw: Not used.
+    :returns: True if the temp patch is absorbed successfully or False
+              if user resolvable conflicts remain
+
+    """
     # Pop the temp patch.
     popped_extra = trans.pop_patches(lambda pn: pn == temp_name)
     assert not popped_extra  # the temp patch was topmost
@@ -264,7 +287,9 @@ def absorb_unapplied(trans, iw, patch_name, temp_name, edit_fun):
     patch_cd = trans.patches[patch_name].data
     temp_cd = trans.patches[temp_name].data
     new_tree = trans.stack.repository.simple_merge(
-        base=temp_cd.parent.data.tree, ours=patch_cd.tree, theirs=temp_cd.tree,
+        base=temp_cd.parent.data.tree,
+        ours=patch_cd.tree,
+        theirs=temp_cd.tree,
     )
     if new_tree:
         # It worked. Refresh the patch with the new tree, and delete
@@ -283,16 +308,17 @@ def absorb_unapplied(trans, iw, patch_name, temp_name, edit_fun):
 
 def absorb(stack, patch_name, temp_name, edit_fun, annotate=None):
     """Absorb the temp patch into the target patch."""
+    log_msg = 'refresh'
     if annotate:
-        log_msg = 'refresh\n\n' + annotate
-    else:
-        log_msg = 'refresh'
+        log_msg += '\n\n' + annotate
+
     trans = StackTransaction(stack, log_msg)
     iw = stack.repository.default_iw
     if patch_name in trans.applied:
         absorb_func = absorb_applied
     else:
         absorb_func = absorb_unapplied
+
     if absorb_func(trans, iw, patch_name, temp_name, edit_fun):
 
         def info_msg():
@@ -311,35 +337,64 @@ def absorb(stack, patch_name, temp_name, edit_fun, annotate=None):
     return r
 
 
-def func(parser, options, args):
-    """Generate a new commit for the current or given patch."""
-
-    # Catch illegal argument combinations.
-    path_limiting = bool(args or options.update)
-    if options.index and path_limiting:
-        raise CmdException('Only full refresh is available with the --index option')
-
-    if options.index and options.force:
-        raise CmdException('You cannot --force a full refresh when using --index mode')
-
-    if options.update and options.submodules:
-        raise CmdException(
-            '--submodules is meaningless when only updating modified files'
-        )
-
-    if options.index and options.submodules:
-        raise CmdException('--submodules is meaningless when keeping the current index')
-
-    # If submodules was not specified on the command line, infer a default
-    # from configuration.
-    if options.submodules is None:
-        options.submodules = config.getbool('stgit.refreshsubmodules')
-
+def __refresh_spill(annotate):
     stack = directory.repository.current_stack
-    patch_name = get_patch(stack, options.patch)
-    paths = list_files(
-        stack, patch_name, args, options.index, options.update, options.submodules,
-    )
+
+    # Fetch the topmost patch.
+    patchname = get_patch(stack, None)
+
+    cd = stack.patches.get(patchname).commit.data
+
+    # Set the tree of the patch to the parent.
+    cd = cd.set_tree(cd.parent.data.tree)
+
+    log_msg = 'refresh (spill)'
+    if annotate:
+        log_msg += '\n\n' + annotate
+
+    trans = StackTransaction(stack, log_msg, allow_conflicts=True)
+    trans.patches[patchname] = stack.repository.commit(cd)
+    try:
+        # Either a complete success, or a conflict during push. But in
+        # either case, we've successfully effected the edits the user
+        # asked us for.
+        return trans.run()
+    except TransactionException:
+        # Transaction aborted -- we couldn't check out files due to
+        # dirty index/worktree. The edits were not carried out.
+        out.error('Unable to spill the topmost patch')
+        return utils.STGIT_COMMAND_ERROR
+
+
+def __refresh(
+    args,
+    force=False,
+    target_patch=None,
+    message=None,
+    author=None,
+    sign_str=None,
+    annotate=None,
+    use_temp_index=False,
+    refresh_from_index=False,
+    only_update_patchfiles=False,
+    include_submodules=False,
+    no_verify=False,
+    invoke_editor=False,
+):
+    stack = directory.repository.current_stack
+
+    patch_name = get_patch(stack, target_patch)
+
+    if refresh_from_index:
+        paths = set()
+    else:
+        paths = list_files(
+            stack,
+            patch_name,
+            args,
+            only_update_patchfiles,
+            include_submodules,
+        )
 
     # Make sure there are no conflicts in the files we want to
     # refresh.
@@ -347,7 +402,7 @@ def func(parser, options, args):
         raise CmdException('Cannot refresh -- resolve conflicts first')
 
     # Make sure the index is clean before performing a full refresh
-    if not options.index and not options.force:
+    if not refresh_from_index and not force:
         if not (
             stack.repository.default_index.is_clean(stack.head)
             or stack.repository.default_iw.worktree_clean()
@@ -357,34 +412,114 @@ def func(parser, options, args):
                 'To force a full refresh use --force.'
             )
 
-    # Commit index to temp patch, and absorb it into the target patch.
-    retval, temp_name = make_temp_patch(
-        stack, patch_name, paths, temp_index=path_limiting
-    )
+    # Update index and write tree
+    tree = write_tree(stack, paths, use_temp_index=use_temp_index)
+
+    # Run pre-commit hook, if fails, abort refresh
+    if not no_verify:
+        pre_commit_hook = get_hook(
+            stack.repository,
+            'pre-commit',
+            extra_env={} if invoke_editor else {'GIT_EDITOR': ':'},
+        )
+        if pre_commit_hook:
+            try:
+                pre_commit_hook()
+            except RunException:
+                raise CmdException(
+                    'pre-commit hook failed, review the changes using `stg diff`, '
+                    'run `stg add` to add them to index and run `stg refresh` again'
+                )
+            else:
+                # Update index and rewrite tree if hook updated files in index
+                if not stack.repository.default_index.is_clean(tree):
+                    tree = write_tree(stack, paths, use_temp_index=use_temp_index)
+
+    # Commit tree to temp patch, and absorb it into the target patch.
+    retval, temp_name = make_temp_patch(stack, patch_name, tree)
+
     if retval != utils.STGIT_SUCCESS:
         return retval
 
     def edit_fun(cd):
         orig_msg = cd.message
+        new_msg = None
+        if message is not None:
+            new_msg = message.encode(config.get('i18n.commitencoding'))
         cd = auto_edit_patch(
             stack.repository,
             cd,
-            msg=(
-                None
-                if options.message is None
-                else options.message.encode(config.get('i18n.commitencoding'))
-            ),
-            author=options.author,
-            sign_str=options.sign_str,
+            msg=new_msg,
+            author=author,
+            sign_str=sign_str,
         )
-        if options.edit:
+        if invoke_editor:
             cd, failed_diff = interactive_edit_patch(
                 stack.repository, cd, edit_diff=False, diff_flags=[]
             )
             assert not failed_diff
-        if not options.no_verify and (options.edit or cd.message != orig_msg):
-            cd = run_commit_msg_hook(stack.repository, cd, options.edit)
+        if not no_verify and (invoke_editor or cd.message != orig_msg):
+            cd = run_commit_msg_hook(stack.repository, cd, invoke_editor)
         # Refresh the committer information
         return cd.set_committer(None)
 
-    return absorb(stack, patch_name, temp_name, edit_fun, annotate=options.annotate)
+    return absorb(stack, patch_name, temp_name, edit_fun, annotate=annotate)
+
+
+def func(parser, options, args):
+    """Generate a new commit for the current or given patch."""
+
+    if options.spill:
+        if (
+            len(args) > 0
+            or options.index
+            or options.edit
+            or options.update
+            or options.patch
+            or options.force
+            or options.no_verify
+            or options.sign_str
+        ):
+            raise CmdException('--spill option does not take any arguments or options')
+        return __refresh_spill(annotate=options.annotate)
+    else:
+        # Catch illegal argument combinations.
+        is_path_limiting = bool(args or options.update)
+        if options.index and is_path_limiting:
+            raise CmdException('Only full refresh is available with the --index option')
+
+        if options.index and options.force:
+            raise CmdException(
+                'You cannot --force a full refresh when using --index mode'
+            )
+
+        if options.update and options.submodules:
+            raise CmdException(
+                '--submodules is meaningless when only updating modified files'
+            )
+
+        if options.index and options.submodules:
+            raise CmdException(
+                '--submodules is meaningless when keeping the current index'
+            )
+
+        # If submodules was not specified on the command line, infer a default
+        # from configuration.
+        if options.submodules is None:
+            options.submodules = config.getbool('stgit.refreshsubmodules')
+
+        return __refresh(
+            args,
+            force=options.force,
+            target_patch=options.patch,
+            message=options.message,
+            author=options.author,
+            sign_str=options.sign_str,
+            annotate=options.annotate,
+            use_temp_index=is_path_limiting,
+            refresh_from_index=options.index,
+            only_update_patchfiles=options.update,
+            include_submodules=options.submodules,
+            no_verify=options.no_verify,
+            invoke_editor=options.edit,
+        )
