@@ -1,10 +1,6 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.commands.common import CmdException, DirectoryGotoTopLevel
 from stgit.lib.transaction import StackTransaction, TransactionHalted
 from stgit.out import out
-from stgit.utils import make_patch_name
 
 __copyright__ = """
 Copyright (C) 2006, Karl Hasselström <kha@treskal.com>
@@ -132,10 +128,7 @@ def func(parser, options, args):
         )
 
         for c in patchify:
-            pn = make_patch_name(
-                c.data.message_str,
-                unacceptable=lambda name: any(p.name == name for p in patches),
-            )
+            pn = stack.patches.make_name(c.data.message_str)
             out.info('Creating patch %s from commit %s' % (pn, c.sha1))
             applied.append(stack.patches.new(pn, c, 'repair'))
         out.done()
@@ -160,7 +153,7 @@ def func(parser, options, args):
             out.info('%s is now hidden' % p.name)
     out.done()
 
-    orig_order = dict((pn, i) for i, pn in enumerate(patchorder.all))
+    orig_order = {pn: i for i, pn in enumerate(patchorder.all)}
 
     def patchname_key(p):
         i = orig_order.get(p, len(orig_order))
