@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import opt, patch_range
 from stgit.commands.common import CmdException, DirectoryHasRepository, parse_patches
 from stgit.config import config
@@ -49,14 +46,24 @@ options = [
         action='store_true',
         short='Show all patches, including the hidden ones',
     ),
-    opt('-A', '--applied', action='store_true', short='Show the applied patches only',),
+    opt(
+        '-A',
+        '--applied',
+        action='store_true',
+        short='Show the applied patches only',
+    ),
     opt(
         '-U',
         '--unapplied',
         action='store_true',
         short='Show the unapplied patches only',
     ),
-    opt('-H', '--hidden', action='store_true', short='Show the hidden patches only',),
+    opt(
+        '-H',
+        '--hidden',
+        action='store_true',
+        short='Show the hidden patches only',
+    ),
     opt(
         '-m',
         '--missing',
@@ -76,7 +83,17 @@ options = [
         action='store_true',
         short='Show a short description for each patch',
     ),
-    opt('--author', action='store_true', short='Show the author name for each patch',),
+    opt(
+        '--no-description',
+        action='store_false',
+        short='Inverse of --description',
+        dest='description',
+    ),
+    opt(
+        '--author',
+        action='store_true',
+        short='Show the author name for each patch',
+    ),
     opt(
         '-e',
         '--empty',
@@ -93,7 +110,9 @@ options = [
         short='Append the branch name to the listed patches',
     ),
     opt(
-        '--noprefix', action='store_true', short='Do not show the patch status prefix',
+        '--noprefix',
+        action='store_true',
+        short='Do not show the patch status prefix',
     ),
     opt(
         '-s',
@@ -107,15 +126,13 @@ directory = DirectoryHasRepository()
 
 
 def __get_description(stack, patch):
-    """Extract and return a patch's short description
-    """
+    """Extract and return a patch's short description"""
     cd = stack.patches.get(patch).commit.data
     return cd.message_str.strip().split('\n', 1)[0].rstrip()
 
 
 def __get_author(stack, patch):
-    """Extract and return a patch's short description
-    """
+    """Extract and return a patch's short description"""
     cd = stack.patches.get(patch).commit.data
     return cd.author.name
 
@@ -149,8 +166,7 @@ def __render_text(text, effects):
 
 
 def __print_patch(stack, patch, branch_str, prefix, length, options, effects):
-    """Print a patch name, description and various markers.
-    """
+    """Print a patch name, description and various markers."""
     if options.noprefix:
         prefix = ''
     elif options.empty:
@@ -177,8 +193,7 @@ def __print_patch(stack, patch, branch_str, prefix, length, options, effects):
 
 
 def func(parser, options, args):
-    """Show the patch series
-    """
+    """Show the patch series"""
     if options.all and options.short:
         raise CmdException('combining --all and --short is meaningless')
 
@@ -187,6 +202,9 @@ def func(parser, options, args):
         cmp_stack = stack
         stack = directory.repository.get_stack(options.missing)
 
+    if options.description is None:
+        options.description = config.getbool('stgit.series.description')
+
     # current series patches
     applied = unapplied = hidden = ()
     if options.applied or options.unapplied or options.hidden:
