@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from stgit import utils
 from stgit.argparse import opt
 from stgit.commands.common import CmdException, DirectoryHasRepository
 from stgit.lib import transaction
@@ -54,9 +50,17 @@ words, you can't uncommit a merge."""
 args = []
 options = [
     opt(
-        '-n', '--number', type='int', short='Uncommit the specified number of commits',
+        '-n',
+        '--number',
+        type='int',
+        short='Uncommit the specified number of commits',
+    ),
+    opt(
+        '-t',
+        '--to',
+        args=['commit'],
+        short='Uncommit to the specified commit',
     ),
-    opt('-t', '--to', args=['commit'], short='Uncommit to the specified commit',),
     opt(
         '-x',
         '--exclusive',
@@ -69,8 +73,7 @@ directory = DirectoryHasRepository()
 
 
 def func(parser, options, args):
-    """Uncommit a number of patches.
-    """
+    """Uncommit a number of patches."""
     stack = directory.repository.current_stack
     if options.to:
         if options.number:
@@ -139,11 +142,13 @@ def func(parser, options, args):
         for pn in patchnames:
             if pn in taken_names:
                 raise CmdException('Patch name "%s" already taken' % pn)
+            elif not stack.patches.is_name_valid(pn):
+                raise CmdException('Patch name "%s" is invalid' % pn)
             taken_names.add(pn)
     else:
         patchnames = []
         for c in reversed(commits):
-            pn = utils.make_patch_name(c.data.message_str, lambda pn: pn in taken_names)
+            pn = stack.patches.make_name(c.data.message_str, disallow=taken_names)
             patchnames.append(pn)
             taken_names.add(pn)
         patchnames.reverse()
