@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-"""Handles the Stacked GIT configuration files"""
-
-from __future__ import absolute_import, division, print_function, unicode_literals
+"""Handles the StGit configuration files."""
 
 import os
 
@@ -34,12 +31,14 @@ DEFAULTS = [
     ('stgit.autoimerge', ['no']),
     ('stgit.fetchcmd', ['git fetch']),
     ('stgit.keepoptimized', ['no']),
+    ('stgit.namelength', ['30']),
     ('stgit.pager', ['less']),
     ('stgit.pick.expose-format', ['format:%B%n(imported from commit %H)']),
     ('stgit.pull-policy', ['pull']),
     ('stgit.pullcmd', ['git pull']),
     ('stgit.refreshsubmodules', ['no']),
     ('stgit.shortnr', ['5']),
+    ('stgit.series.description', ['no']),
     ('stgit.smtpdelay', ['5']),
     ('stgit.smtpserver', ['localhost:25']),
 ]
@@ -49,7 +48,7 @@ class GitConfigException(StgException):
     pass
 
 
-class GitConfig(object):
+class GitConfig:
 
     _cache = None
 
