@@ -1,18 +1,15 @@
-# -*- coding: utf-8 -*-
 """Basic quilt-like functionality"""
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import os
 import sys
 import traceback
 
+import stgit.commands
 from stgit import argparse, run, utils
 from stgit.compat import environ_get, fsdecode_utf8
 from stgit.config import config
 from stgit.out import out
 from stgit.pager import pager
-import stgit.commands
 
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
@@ -31,7 +28,7 @@ along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 
-class CommandAlias(object):
+class CommandAlias:
     def __init__(self, name, command):
         self._command = command
         self.__name__ = name
@@ -60,13 +57,10 @@ def append_alias_commands(cmd_list):
 # The commands map
 #
 class Commands(dict):
-    """Commands class. It performs on-demand module loading
-    """
+    """Commands class. It performs on-demand module loading"""
 
     def canonical_cmd(self, key):
-        """Return the canonical name for a possibly-shortenned
-        command name.
-        """
+        """Return the canonical name for a possibly-shortened command name."""
         candidates = [cmd for cmd in self if cmd.startswith(key)]
 
         if not candidates:
@@ -108,12 +102,7 @@ def print_help():
     stgit.commands.pretty_command_list(cmd_list, sys.stdout)
 
 
-#
-# The main function (command dispatcher)
-#
 def _main():
-    """The main function
-    """
     global prog
 
     sys.argv = list(map(fsdecode_utf8, sys.argv))
@@ -173,11 +162,11 @@ def _main():
     # These modules are only used from this point onwards and do not
     # need to be imported earlier
     try:
-        from configparser import ParsingError, NoSectionError
+        from configparser import NoSectionError, ParsingError
     except ImportError:
-        from ConfigParser import ParsingError, NoSectionError
-    from stgit.exception import StgException
+        from ConfigParser import NoSectionError, ParsingError
     from stgit.config import config_setup
+    from stgit.exception import StgException
     from stgit.lib.git import MergeConflictException
 
     try:
