@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import datetime
 import io
+import os
 import subprocess
 
-from stgit.compat import environ_copy, environ_get, file_wrapper, fsencode_utf8, text
+from stgit.compat import environ_get, fsencode_utf8
 from stgit.exception import StgException
 from stgit.out import MessagePrinter, out
 
@@ -27,10 +25,7 @@ along with this program; if not, see http://www.gnu.org/licenses/.
 
 
 class RunException(StgException):
-    """Thrown when something bad happened when we tried to run the
-    subprocess."""
-
-    pass
+    """Exception raised for subprocess failures."""
 
 
 def get_log_mode(spec):
@@ -74,14 +69,11 @@ def finish_logging():
     )
 
 
-class Run(object):
+class Run:
     exc = RunException
 
     def __init__(self, *cmd):
         self._cmd = list(cmd)
-        for c in cmd:
-            if not isinstance(c, text):
-                raise Exception('Bad command: %r' % (cmd,))
         self._good_retvals = [0]
         self._env = self._cwd = None
         self._indata = None
@@ -93,10 +85,9 @@ class Run(object):
         return [fsencode_utf8(c) for c in self._cmd]
 
     def _prep_env(self):
-        if self._env:
-            return dict(
-                (fsencode_utf8(k), fsencode_utf8(v)) for k, v in self._env.items()
-            )
+        # Windows requires a dict of strings as env parameter, so don't encode for Windows
+        if self._env and os.name != 'nt':
+            return {fsencode_utf8(k): fsencode_utf8(v) for k, v in self._env.items()}
         else:
             return self._env
 
@@ -163,7 +154,11 @@ class Run(object):
         assert self._indata is None
         self._log_start()
         try:
-            p = subprocess.Popen(self._prep_cmd(), env=self._prep_env(), cwd=self._cwd,)
+            p = subprocess.Popen(
+                self._prep_cmd(),
+                env=self._prep_env(),
+                cwd=self._cwd,
+            )
             self.exitcode = p.wait()
         except OSError as e:
             raise self.exc('%s failed: %s' % (self._cmd[0], e))
@@ -185,12 +180,7 @@ class Run(object):
         except OSError as e:
             raise self.exc('%s failed: %s' % (self._cmd[0], e))
         if self._in_encoding:
-            if hasattr(p.stdin, 'readable'):
-                self.stdin = io.TextIOWrapper(p.stdin, encoding=self._in_encoding)
-            else:
-                self.stdin = io.TextIOWrapper(
-                    file_wrapper(p.stdin, writable=True), encoding=self._in_encoding
-                )
+            self.stdin = io.TextIOWrapper(p.stdin, encoding=self._in_encoding)
         else:
             self.stdin = p.stdin
         self.stdout = p.stdout
@@ -212,7 +202,7 @@ class Run(object):
         return self
 
     def env(self, env):
-        self._env = environ_copy()
+        self._env = os.environ.copy()
         self._env.update(env)
         return self
 
