@@ -7,14 +7,18 @@ test_expect_success 'Setup' '
     printf "000\n111\n222\n333\n" >> foo &&
     stg add foo &&
     git commit -m "Initial commit" &&
-    sed -i "s/000/000xx/" foo &&
+    sed "s/000/000xx/" foo > foo.tmp && mv foo.tmp foo &&
     git commit -a -m "First change" &&
-    sed -i "s/111/111yy/" foo &&
+    git notes add -m note1 &&
+    sed "s/111/111yy/" foo > foo.tmp && mv foo.tmp foo &&
     git commit -a -m "Second change" &&
-    sed -i "s/222/222zz/" foo &&
+    git notes add -m note2 &&
+    sed "s/222/222zz/" foo > foo.tmp && mv foo.tmp foo &&
     git commit -a -m "Third change" &&
-    sed -i "s/333/333zz/" foo &&
+    git notes add -m note3 &&
+    sed "s/333/333zz/" foo > foo.tmp && mv foo.tmp foo &&
     git commit -a -m "Fourth change" &&
+    git notes add -m note4 &&
     stg init &&
     stg uncommit -n 4 p &&
     stg pop -n 2 &&
@@ -27,28 +31,44 @@ msg () { git cat-file -p $1 | sed '1,/^$/d' | tr '\n' / | sed 's,/*$,,' ; }
 auth () { git log -n 1 --pretty=format:"%an, %ae" $1 ; }
 adate () { git log -n 1 --pretty=format:%ai $1 ; }
 
+write_script diffedit <<EOF
+sed 's/empty-patch/Empty Patch/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Edit new patch with no diff' '
+    stg new -m empty-patch &&
+    test_when_finished stg delete empty-patch &&
+    EDITOR=./diffedit stg edit -d &&
+    test "$(msg HEAD)" = "Empty Patch"
+'
+rm -f diffedit
+
 test_expect_success 'Edit message of top patch' '
     test "$(msg HEAD)" = "Second change" &&
     stg edit p2 -m "Second change 2" &&
-    test "$(msg HEAD)" = "Second change 2"
+    test "$(msg HEAD)" = "Second change 2" &&
+    test "$(git notes show $(stg id p2))" = "note2"
 '
 
 test_expect_success 'Edit message of non-top patch' '
     test "$(msg HEAD^)" = "First change" &&
     stg edit p1 -m "First change 2" &&
-    test "$(msg HEAD^)" = "First change 2"
+    test "$(msg HEAD^)" = "First change 2" &&
+    test "$(git notes show $(stg id p1))" = "note1"
+
 '
 
 test_expect_success 'Edit message of unapplied patch' '
     test "$(msg $(stg id p3))" = "Third change" &&
     stg edit p3 -m "Third change 2" &&
-    test "$(msg $(stg id p3))" = "Third change 2"
+    test "$(msg $(stg id p3))" = "Third change 2" &&
+    test "$(git notes show $(stg id p3))" = "note3"
 '
 
 test_expect_success 'Edit message of hidden patch' '
     test "$(msg $(stg id p4))" = "Fourth change" &&
     stg edit p4 -m "Fourth change 2" &&
-    test "$(msg $(stg id p4))" = "Fourth change 2"
+    test "$(msg $(stg id p4))" = "Fourth change 2" &&
+    test "$(git notes show $(stg id p4))" = "note4"
 '
 
 test_expect_success 'Set patch message with --file <file>' '
@@ -64,7 +84,7 @@ test_expect_success 'Set patch message with --file -' '
 '
 
 ( printf 'From: A Ú Thor <author@example.com>\nDate: <omitted>'
-  printf '\n\nPride and Prejudice' ) > expected-tmpl
+  printf '\n\nPride and Prejudice\n' ) > expected-tmpl
 omit_date () { sed "s/^Date:.*$/Date: <omitted>/" ; }
 
 test_expect_success 'Save template to file' '
@@ -91,15 +111,14 @@ test_expect_success 'Save template to stdout' '
 
 mkeditor ()
 {
-    cat > "$1" <<EOF
-#!/bin/sh
-printf "\n$1" >> "\$1"
+    write_script "$1" <<EOF
+printf "$1" >> "\$1"
 EOF
-    chmod a+x "$1"
 }
 
 mkeditor vi
 test_expect_success 'Edit commit message interactively (vi)' '
+    unset EDITOR
     m=$(msg HEAD) &&
     PATH=.:$PATH stg edit p2 &&
     test "$(msg HEAD)" = "$m/vi"
@@ -154,11 +173,9 @@ test_expect_success 'Both noninterative and interactive editing' '
 '
 rm -f twoliner
 
-cat > diffedit <<EOF
-#!/bin/sh
-sed -i 's/111yy/111YY/' "\$1"
+write_script diffedit <<EOF
+sed 's/111yy/111YY/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
 EOF
-chmod a+x diffedit
 test_expect_success 'Edit patch diff' '
     EDITOR=./diffedit stg edit -d p2 &&
     test "$(grep 111 foo)" = "111YY"
@@ -222,7 +239,7 @@ test_expect_success 'Set author date to "now"' '
     before=$(date "+%F %T %z") &&
     stg edit p2 --authdate now &&
     after=$(date "+%F %T %z") &&
-    printf "$before\n$(adate HEAD)\n$after\n" | sort -C -
+    printf "$before\n$(adate HEAD)\n$after\n" | sort -c -
 '
 
 test_expect_success 'Set patch tree' '
@@ -237,7 +254,11 @@ test_expect_success 'Set patch tree' '
     test "$(git write-tree)" = "$p2tree" &&
     grep "^333$" foo &&
     stg edit --set-tree $p2tree p1 &&
-    test "$(echo $(stg series --empty --all))" = "+ p1 0> p2 - p3 ! p4"
+    test "$(echo $(stg series --empty --all))" = "+ p1 0> p2 - p3 ! p4" &&
+    test "$(git notes show $(stg id p1))" = "note1" &&
+    test "$(git notes show $(stg id p2))" = "note2" &&
+    test "$(git notes show $(stg id p3))" = "note3" &&
+    test "$(git notes show $(stg id p4))" = "note4"
 '
 
 test_done
